==> dateparser_1.0.0.orig.tar.gz: dateparser-1.0.0/dateparser/data/date_translation_data/si.py <==
info = {
    "name": "si",
    "date_order": "YMD",
    "january": [
        "ජනවාරි",
        "ජන"
    ],
    "february": [
        "පෙබරවාරි",
        "පෙබ"
    ],
    "march": [
        "මාර්තු",
        "මාර්"
    ],
    "april": [
        "අප්‍රේල්"
    ],
    "may": [
        "මැයි"
    ],
    "june": [
        "ජූනි"
    ],
    "july": [
        "ජූලි"
    ],
    "august": [
        "අගෝස්තු",
        "අගෝ"
    ],
    "september": [
        "සැප්තැම්බර්",
        "සැප්"
    ],
    "october": [
        "ඔක්තෝබර්",
        "ඔක්"
    ],
    "november": [
        "නොවැම්බර්",
        "නොවැ"
    ],
    "december": [
        "දෙසැම්බර්",
        "දෙසැ"
    ],
    "monday": [
        "සඳුදා"
    ],
    "tuesday": [
        "අඟහරුවාදා",
        "අඟහ"
    ],
    "wednesday": [
        "බදාදා"
    ],
    "thursday": [
        "බ්‍රහස්පතින්දා",
        "බ්‍රහස්"
    ],
    "friday": [
        "සිකුරාදා",
        "සිකු"
    ],
    "saturday": [
        "සෙනසුරාදා",
        "සෙන"
    ],
    "sunday": [
        "ඉරිදා"
    ],
    "am": [
        "පෙව"
    ],
    "pm": [
        "පව"
    ],
    "year": [
        "වර්ෂය",
        "වර්"
    ],
    "month": [
        "මාසය",
        "මාස"
    ],
    "week": [
        "සතිය",
        "සති"
    ],
    "day": [
        "දිනය"
    ],
    "hour": [
        "පැය",
        "පැ"
    ],
    "minute": [
        "මිනිත්තුව",
        "මිනි",
        "මි"
    ],
    "second": [
        "තත්පරය",
        "තත්",
        "ත"
    ],
    "relative-type": {
        "1 year ago": [
            "පසුගිය වසර"
        ],
        "0 year ago": [
            "මෙම වසර"
        ],
        "in 1 year": [
            "ඊළඟ වසර"
        ],
        "1 month ago": [
            "පසුගිය මාසය",
            "පසුගිය මාස"
        ],
        "0 month ago": [
            "මෙම මාසය",
            "මෙම මාස"
        ],
        "in 1 month": [
            "ඊළඟ මාසය",
            "ඊළඟ මාස"
        ],
        "1 week ago": [
            "පසුගිය සතිය",
            "පසුගිය සති"
        ],
        "0 week ago": [
            "මෙම සතිය",
            "මෙම සති"
        ],
        "in 1 week": [
            "ඊළඟ සතිය",
            "ඊළඟ සති"
        ],
        "1 day ago": [
            "ඊයේ"
        ],
        "0 day ago": [
            "අද"
        ],
        "in 1 day": [
            "හෙට"
        ],
        "0 hour ago": [
            "මෙම පැය"
        ],
        "0 minute ago": [
            "මෙම මිනිත්තුව"
        ],
        "0 second ago": [
            "දැන්"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "වසර (\\d+)කින්"
        ],
        "\\1 year ago": [
            "වසර (\\d+)කට පෙර"
        ],
        "in \\1 month": [
            "මාස (\\d+)කින්"
        ],
        "\\1 month ago": [
            "මාස (\\d+)කට පෙර"
        ],
        "in \\1 week": [
            "සති (\\d+)කින්"
        ],
        "\\1 week ago": [
            "සති (\\d+)කට පෙර"
        ],
        "in \\1 day": [
            "දින (\\d+)න්"
        ],
        "\\1 day ago": [
            "දින (\\d+)කට පෙර"
        ],
        "in \\1 hour": [
            "පැය (\\d+)කින්"
        ],
        "\\1 hour ago": [
            "පැය (\\d+)කට පෙර"
        ],
        "in \\1 minute": [
            "මිනිත්තු (\\d+)කින්"
        ],
        "\\1 minute ago": [
            "මිනිත්තු (\\d+)කට පෙර"
        ],
        "in \\1 second": [
            "තත්පර (\\d+)කින්"
        ],
        "\\1 second ago": [
            "තත්පර (\\d+)කට පෙර"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}

==> dateparser_1.1.0.orig.tar.gz: dateparser-1.1.0/dateparser/data/date_translation_data/si.py <==
info = {
    "name": "si",
    "date_order": "YMD",
    "january": [
        "ජන",
        "ජනවාරි"
    ],
    "february": [
        "පෙබ",
        "පෙබරවාරි"
    ],
    "march": [
        "මාර්",
        "මාර්තු"
    ],
    "april": [
        "අප්‍රේල්"
    ],
    "may": [
        "මැයි"
    ],
    "june": [
        "ජූනි"
    ],
    "july": [
        "ජූලි"
    ],
    "august": [
        "අගෝ",
        "අගෝස්තු"
    ],
    "september": [
        "සැප්",
        "සැප්තැම්බර්"
    ],
    "october": [
        "ඔක්",
        "ඔක්තෝබර්"
    ],
    "november": [
        "නොවැ",
        "නොවැම්බර්"
    ],
    "december": [
        "දෙසැ",
        "දෙසැම්බර්"
    ],
    "monday": [
        "සඳුදා"
    ],
    "tuesday": [
        "අඟහ",
        "අඟහරුවාදා"
    ],
    "wednesday": [
        "බදාදා"
    ],
    "thursday": [
        "බ්‍රහස්",
        "බ්‍රහස්පතින්දා"
    ],
    "friday": [
        "සිකු",
        "සිකුරාදා"
    ],
    "saturday": [
        "සෙන",
        "සෙනසුරාදා"
    ],
    "sunday": [
        "ඉරිදා"
    ],
    "am": [
        "පෙව"
    ],
    "pm": [
        "පව"
    ],
    "year": [
        "වර්",
        "වර්ෂය"
    ],
    "month": [
        "මාස",
        "මාසය"
    ],
    "week": [
        "සති",
        "සතිය"
    ],
    "day": [
        "දිනය"
    ],
    "hour": [
        "පැ",
        "පැය"
    ],
    "minute": [
        "මි",
        "මිනි",
        "මිනිත්තුව"
    ],
    "second": [
        "ත",
        "තත්",
        "තත්පරය"
    ],
    "relative-type": {
        "0 day ago": [
            "අද"
        ],
        "0 hour ago": [
            "මෙම පැය"
        ],
        "0 minute ago": [
            "මෙම මිනිත්තුව"
        ],
        "0 month ago": [
            "මෙම මාස",
            "මෙම මාසය"
        ],
        "0 second ago": [
            "දැන්"
        ],
        "0 week ago": [
            "මෙම සති",
            "මෙම සතිය"
        ],
        "0 year ago": [
            "මෙම වසර"
        ],
        "1 day ago": [
            "ඊයේ"
        ],
        "1 month ago": [
            "පසුගිය මාස",
            "පසුගිය මාසය"
        ],
        "1 week ago": [
            "පසුගිය සති",
            "පසුගිය සතිය"
        ],
        "1 year ago": [
            "පසුගිය වසර"
        ],
        "in 1 day": [
            "හෙට"
        ],
        "in 1 month": [
            "ඊළඟ මාස",
            "ඊළඟ මාසය"
        ],
        "in 1 week": [
            "ඊළඟ සති",
            "ඊළඟ සතිය"
        ],
        "in 1 year": [
            "ඊළඟ වසර"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "දින (\\d+)කට පෙර"
        ],
        "\\1 hour ago": [
            "පැය (\\d+)කට පෙර"
        ],
        "\\1 minute ago": [
            "මිනිත්තු (\\d+)කට පෙර"
        ],
        "\\1 month ago": [
            "මාස (\\d+)කට පෙර"
        ],
        "\\1 second ago": [
            "තත්පර (\\d+)කට පෙර"
        ],
        "\\1 week ago": [
            "සති (\\d+)කට පෙර"
        ],
        "\\1 year ago": [
            "වසර (\\d+)කට පෙර"
        ],
        "in \\1 day": [
            "දින (\\d+)න්"
        ],
        "in \\1 hour": [
            "පැය (\\d+)කින්"
        ],
        "in \\1 minute": [
            "මිනිත්තු (\\d+)කින්"
        ],
        "in \\1 month": [
            "මාස (\\d+)කින්"
        ],
        "in \\1 second": [
            "තත්පර (\\d+)කින්"
        ],
        "in \\1 week": [
            "සති (\\d+)කින්"
        ],
        "in \\1 year": [
            "වසර (\\d+)කින්"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
